#
# spec file for package upm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 1
Name:           upm
Version:        2.0.0
Release:        bp156.4.4
Summary:        High-level repository for sensors that use mraa
License:        MIT
Group:          Hardware/Other
URL:            https://github.com/eclipse/upm
Source:         %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch:          %{url}/pull/704.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  swig
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(mraa) >= 2.0.0
BuildRequires:  pkgconfig(python3)
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64

%description
The UPM repository provides software drivers for a wide variety of commonly
used sensors and actuators. These software drivers interact with the
underlying hardware platform (or microcontroller), as well as with the
attached sensors, through calls to MRAA APIs.

%package -n lib%{name}%{sover}
Summary:        High-level repository for sensors that use mraa
Group:          System/Libraries

%description -n lib%{name}%{sover}
The UPM repository provides software drivers for a wide variety of commonly
used sensors and actuators. These software drivers interact with the
underlying hardware platform (or microcontroller), as well as with the
attached sensors, through calls to MRAA APIs.

This package contains shared library for %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       lib%{name}%{sover} = %{version}

%description devel
The UPM repository provides software drivers for a wide variety of commonly
used sensors and actuators. These software drivers interact with the
underlying hardware platform (or microcontroller), as well as with the
attached sensors, through calls to MRAA APIs.

Programmers can access the interfaces for each sensor by including the
sensor’s corresponding header file and instantiating the associated sensor
class. In the typical use case, a constructor initializes the sensor based
on parameters that identify the sensor, the I/O protocol used and the pin
location of the sensor.

This package contains development files for %{name}.

%package -n python3-%{name}
Summary:        Python bindings for %{name}
Group:          Development/Languages/Python
Requires:       lib%{name}%{sover} = %{version}

%description -n python3-%{name}
The UPM repository provides software drivers for a wide variety of commonly
used sensors and actuators. These software drivers interact with the
underlying hardware platform (or microcontroller), as well as with the
attached sensors, through calls to MRAA APIs.

This package contains python3 bindings for %{name}.

%package -n nodejs-%{name}
Summary:        Nodejs bindings for %{name}
Group:          Development/Languages/Other
%requires_ge    nodejs6

%description -n nodejs-%{name}
The UPM repository provides software drivers for a wide variety of commonly
used sensors and actuators. These software drivers interact with the
underlying hardware platform (or microcontroller), as well as with the
attached sensors, through calls to MRAA APIs.

This package contains nodejs bindings for %{name}.

%prep
%autosetup -p1
# remove CC BY-NC-SA 3.0 licenced images
rm -rf docs/images

%build
%define __builder ninja
%cmake \
  -DCMAKE_SHARED_LINKER_FLAGS="" \
  -DCMAKE_EXE_LINKER_FLAGS="" \
  -DCMAKE_MODULE_LINKER_FLAGS="" \
  -DBUILDSWIGNODE=off \
  -DBUILDFTI=on \
  -Wno-dev
%cmake_build

%install
%cmake_install
sed -i "s|jpeg|libjpeg|g" %{buildroot}%{_libdir}/pkgconfig/upm-vcap.pc
rm -rf %{buildroot}%{_datadir}/upm

%ldconfig_scriptlets -n lib%{name}%{sover}

%files -n lib%{name}%{sover}
%license LICENSE
%doc README.md
%{_libdir}/lib%{name}*.so.%{sover}*

%files devel
%{_libdir}/lib%{name}*.so
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}*

%files -n python3-%{name}
%{python3_sitearch}/*

%changelog
* Sat Apr  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream pull req patch: 704.patch -- include missing
  <cstdint>. Fix build with gcc 13.
- Use autosetup and ldconfig_scriptlets macros.
- Update URL and Source to new home.
* Tue May  5 2020 Martin Pluskal <mpluskal@suse.com>
- Fix dependency of devel package on libjpeg
* Tue Apr 28 2020 Martin Pluskal <mpluskal@suse.com>
- Drop python2 support
- Re-enable LTO
* Wed Aug 14 2019 Martin Pluskal <mpluskal@suse.com>
- Disable LTO (currently broken)
* Wed May 29 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.0.0:
  * Reworked existing interfaces
  * Provided overloaded string based constructors for a good number
    of sensors, allowing initialization from external frameworks
    without type knowledge
  * Removed deprecated basic grove classes from project
  * Replaced 6 unsafe occurrences of sprintf() usage
  * Cleaned-up build system around target arch detection and cpack
    usage, added detection and resolution of tinyb library when
    used as a dependency
* Mon Mar 11 2019 Martin Pluskal <mpluskal@suse.com>
- Drop building of nodejs bindings as they dont build with latest
  node.
* Thu Jan 10 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.7.1:
  * Bumped library compatibility to new MRAA 2.0 APIs
  * Added installation details for Fedora
  * Minor fixes based on static analysis vulnerability report
- Changes for version 1.7.0:
  * Added Cordova bindings based on Java packages
  * Complete rework of the nmea_gps library giving more control
    over data acquisition and parsing
  * Added GTest support for unit tests
  * Removed calls to deprecated MRAA fast GPIO functions
  * Several bug fixes and improvements around SWIG type maps and
    gcc8 support
  * New sensors: kx122, kxtj3, bh1792, bh1749
- Run tests during build
* Tue Jul 10 2018 mpluskal@suse.com
- Update to version 1.6.0:
  * Extended LED library to support the new MRAA gpio-leds APIs
  * Many CMake changes around SWIG wrapper generation and improved
    FindNodejs detection module
  * Several code fixes based on static code analysis
  * Improved documentation generation and Travis CI builds
  * Cleaned-up doxygen tags in headers and class names in JSON
    library files
  * New sensor: lis3dh
- Enable building of nodejs bindings
* Tue Nov  7 2017 mpluskal@suse.com
- Update to version 1.5.0:
  * Introduced a flexible JSON format for technical sensor
    specifications, notes and classification. This is also used by
    our new UPM website
  * Revised all C++ sensor examples and switched to stack
    allocations where possible along with other code and formatting
    clean-up
  * Significantly improved docker workflow, CI integration, sanity
    and consistency tests, static code scans and documentation
    generation
  * Several improvements to a couple of existing sensor drivers and
    better compatibility with subplatforms
  * Added new std::vector to AbstractList<> typemap for Java
    bindings and examples
  * New sensors: lis2ds12, lsm6ds3h, lsm6dsl, lidarlitev3
- Drop no longer needed upm-ads1x15.patch
- Rename python subpackage to python2
* Thu Aug  3 2017 mpluskal@suse.com
- Explicitly remove non free parts
* Mon Jun  5 2017 mpluskal@suse.com
- Update to version 1.3.0:
  * Finalized all required build system and JAVA binding changes to
    release the UPM libraries for Android Things targets
  * Enhanced the modules for lsm303 and tmp006 to support newer
    variants of the chips
  * Fixed Node.js detection on Ubuntu when installed with apt using
    official packages
  * Minor documentation changes
  * New sensors: lsm303agr, lsm303d, veml6070, tca9548a, rn2903
- Changes for version 1.2.0:
  * Improved JAVA binding compiler compatibility and added JAVA
    interfaces that match existing C++ interfaces
  * Ported Bosch drivers to C thus now they can be used on
    supported MCUs
  * Completely redesigned C/C++ example handling by cmake to avoid
    maintaining a list by hand
  * Fixed several existing drivers, mostly based on static code
    analysis reports
  * Added a sensor driver template plus bash script that can be
    easily used by developers to start writing their own sensor
    driver
  * Numerous documentation improvements
  * New sensors: p9813, abp, rsc, mmc35240, tcs37727, tmp006,
    mma8x6x, mag3110, hdc1000
- Changes for version 1.1.0:
  * Reworked cmake handling of internal and external dependencies
  * Documentation improvements for sensor names, sensor
    descriptions, external contributor guides and added new section
    on installing UPM on a supported OS
  * Fixed issues with C11 builds on some WRLinux gateways and
    Debian systems
  * New examples and functionality for speaker and ads1x15 modules
  * Modified JAVA builds to ensure the SWIG generated wrappers
    include all functionality and typemaps
  * New sensors: mcp2515, max30100, uartat, le910
- Add upm-ads1x15.patch to fix building with gcc7
- Use ninja for building
* Thu Jan 26 2017 mpluskal@suse.com
- Update to version 1.0.3:
  * Minor cmake changes for Java builds and Java examples are now
    toggled with the same BUILDEXAMPLES cmake switch
  * Made some improvements in the utilities class for our C drivers
  * Fixed issue with some drivers not being usable on subplatforms
    due to pin numbers using uint8 type
  * New sensors: ims, ecezo, mb704x, rf22
- Changes for version 1.0.1:
  * Warnings as errors enabled for C/CXX (fixed warnings from -Wall
    and others)
  * Fix for C/CXX compile flag append issue #485
  * C sensor libraries for: my9221, otp538u, guvas12d, ppd42ns
  * New sensor: ms5803
- Changes for version 1.0.0:
  * Added approximately 50 C sources for UPM drivers that can be
    used on both Unix and RTOS boards
  * Provided generic alternatives to the Grove set of classes as
    they will be deprecated over time and eventually removed
  * UPM modules are now being packed and published on NPM as
    sources rather than binaries to enhance compatibility with
    various boards and systems
  * Build both python2 and python3 modules if the corresponding
    python libs are available and removed cmake BUILDPYTHON3 switch
  * Converted python examples to run on both python2 and python3
  * Added 'upm' hierarchy to python module install path which
    changes the way UPM modules are imported Example: old: import
    pyupm_dfrph new: from upm import pyupm_dfrph or import
    upm.pyupm_dfrph
  * Added ctests for consistancy checking UPM repo as well as
    sanity checking for python2/3 modules and examples
  * Various documentation and driver fixes throughout
  * New sensors: nmea_gps, mma7361, bh1750, hka5, dfrorp, dfrec,
    sht1x
* Mon Oct  3 2016 jengelh@inai.de
- Trim/edit description
* Wed Sep 28 2016 mpluskal@suse.com
- Initial package for version 0.8.0
